@@ -1,45 +1,42 @@
 #' Handling outliers in single-case data
-#' 
+#'
 #' Identifies and drops outliers within a single-case data frame (scdf).
-#' 
-#' 
+#'
+#'
 #' @inheritParams .inheritParams
 #' @param criteria Specifies the criteria for outlier identification. Set
-#' \code{criteria = c("SD", 2)} to define two standard deviations as limit.
-#' This is also the default setting. To use the 99\% Confidence Interval use
-#' \code{criteria = c("CI", 0.99)}. Set \code{criteria = c("Cook", "4/n")} to
-#' define any data point with a Cook's Distance greater than 4/n as an outlier,
-#' based on the Piecewise Linear Regression Model.
-#' @return 
-#' \item{data}{A single-case data frame with substituted outliers.}
+#'   \code{criteria = c("SD", 2)} to define two standard deviations as limit.
+#'   This is also the default setting. To use the 99\% Confidence Interval use
+#'   \code{criteria = c("CI", 0.99)}. Set \code{criteria = c("Cook", "4/n")} to
+#'   define any data point with a Cook's Distance greater than 4/n as an
+#'   outlier, based on the Piecewise Linear Regression Model.
+#' @return \item{data}{A single-case data frame with substituted outliers.}
 #' \item{dropped.n}{A list with the number of dropped data points for each
-#' single-case.}
-#' \item{dropped.mt}{A list with the measurement-times of dropped
+#' single-case.} \item{dropped.mt}{A list with the measurement-times of dropped
 #' data points for each single-case (values are based on the \code{mt} variable
-#' of each single-case data frame).} 
-#' \item{sd.matrix}{A list with a matrix for each case with values for the 
-#' upper and lower boundaries based on the standard deviation.} 
-#' \item{ci.matrix}{A list with a matrix for each single-case with values 
-#' for the upper and lower boundaries based on the confidence interval.} 
-#' \item{cook}{A list of Cook's Distances for each measurement of each single-case.} 
-#' \item{criteria}{Criteria used for outlier analysis.} 
-#' \item{N}{Number of single-cases.} 
-#' \item{case.names}{Case identifier.}
+#' of each single-case data frame).} \item{sd.matrix}{A list with a matrix for
+#' each case with values for the upper and lower boundaries based on the
+#' standard deviation.} \item{ci.matrix}{A list with a matrix for each
+#' single-case with values for the upper and lower boundaries based on the
+#' confidence interval.} \item{cook}{A list of Cook's Distances for each
+#' measurement of each single-case.} \item{criteria}{Criteria used for outlier
+#' analysis.} \item{N}{Number of single-cases.} \item{case.names}{Case
+#' identifier.}
 #' @author Juergen Wilbert
 #' @family data manipulation functions
 #' @keywords manip
 #' @examples
-#' 
+#'
 #' ## Identify outliers using 1.5 standard deviations as criterion
-#' susanne <- rSC(level = 1.0)
+#' susanne <- random_scdf(level = 1.0)
 #' res_outlier <- outlier(susanne, criteria = c("SD", 1.5))
 #' plot(susanne, marks = res_outlier)
-#' 
+#'
 #' ## Identify outliers in the original data from Grosche (2011) using Cook's Distance
 #' ## greater than 4/n as criterion
 #' res_outlier <- outlier(Grosche2011, criteria = c("Cook", "4/n"))
 #' plot(Grosche2011, marks = res_outlier)
-#' 
+#'
 #' @export
 outlier <- function(data, dvar, pvar, mvar, criteria = c("MAD", "3.5")) {
   
@@ -47,10 +44,14 @@ outlier <- function(data, dvar, pvar, mvar, criteria = c("MAD", "3.5")) {
     stop("Unknown criteria. Please check.")
   }
   
-  # set attributes to arguments else set to defaults of scdf
-  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) else scdf_attr(data, .opt$dv) <- dvar
-  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) else scdf_attr(data, .opt$phase) <- pvar
-  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) else scdf_attr(data, .opt$mt) <- mvar
+  # set defaults attributes
+  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) 
+  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) 
+  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) 
+  
+  scdf_attr(data, .opt$dv) <- dvar
+  scdf_attr(data, .opt$phase) <- pvar
+  scdf_attr(data, .opt$mt) <- mvar
   
   data_list <- .prepare_scdf(data)
  
@@ -174,9 +175,9 @@ outlier <- function(data, dvar, pvar, mvar, criteria = c("MAD", "3.5")) {
   out
 }
 
-#' @rdname outlier
+#' @rdname deprecated-functions
 #' @export
 outlierSC <- function(...) {
   .deprecated_warning("outlier", "outlierSC")
   outlier(...)
-}
\ No newline at end of file
+}
