@@ -85,17 +85,3 @@ style_plot <- function(style = "default", ...) {
   }
   invisible(out)
 }
-
-#' @rdname style_plot
-#' @export
-style_plotSC <- function(...) {
-  .deprecated_warning("style_plot", "style_plotSC")
-  style_plot(...)
-}
-
-#' @rdname style_plot
-#' @export
-style.plotSC <- function(...) {
-  .deprecated_warning("style_plot", "style.plotSC")  
-  style_plot(...)
-}
\ No newline at end of file
